@@ -1,12 +1,12 @@
-use strict;
-use warnings;
-
 package SVN::Hooks::Generic;
 {
-  $SVN::Hooks::Generic::VERSION = '1.23';
+  $SVN::Hooks::Generic::VERSION = '1.27';
 }
 # ABSTRACT: Implement generic checks for all Subversion hooks.
 
+use strict;
+use warnings;
+
 use Carp;
 use Data::Util qw(:check);
 use SVN::Hooks;
@@ -34,7 +34,7 @@ sub GENERIC {
 	}
 	foreach my $foo (@$functions) {
 	    is_code_ref($foo) or die "$HOOK: hook '$hook' should be mapped to CODE-refs.\n";
-	    $SVN::Hooks::Hooks{$hook}{$foo} ||= sub { $foo->(@_); };
+	    push @{$SVN::Hooks::Hooks{$hook}}, sub { $foo->(@_); };
 	}
     }
 
@@ -55,7 +55,7 @@ SVN::Hooks::Generic - Implement generic checks for all Subversion hooks.
 
 =head1 VERSION
 
-version 1.23
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -132,7 +132,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by CPqD.
+This software is copyright (c) 2014 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
