@@ -1,12 +1,12 @@
-use strict;
-use warnings;
-
 package SVN::Hooks::UpdateConfFile;
 {
-  $SVN::Hooks::UpdateConfFile::VERSION = '1.23';
+  $SVN::Hooks::UpdateConfFile::VERSION = '1.27';
 }
 # ABSTRACT: Maintain the repository configuration versioned.
 
+use strict;
+use warnings;
+
 use Carp;
 use Data::Util qw(:check);
 use File::Spec::Functions;
@@ -112,6 +112,7 @@ sub post_commit {
 	my $from = $conf->{from};
 	for my $file ($svnlook->added(), $svnlook->updated()) {
             my $to = _post_where_to($absbase, $file, $from, $conf->{to});
+            next unless defined $to;
 
 	    my $text = $svnlook->cat($file);
 
@@ -133,8 +134,16 @@ $@
 EOS
 	    }
 
+            # Create the directory where $to is to be created, if it doesn't
+            # already exist.
+            my $todir = (File::Spec->splitpath($to))[1];
+            unless (-d $todir) {
+                require File::Path;
+                File::Path::make_path($todir);
+            }
+
 	    open my $fd, '>', "$to.new"
-		or croak "$HOOK: Can't open file \"$to\" for writing: $!\n";
+		or croak "$HOOK: Can't open file \"$to.new\" for writing: $!\n";
 	    print $fd $text;
 	    close $fd;
 
@@ -166,7 +175,7 @@ EOS
         if ($conf->{remove}) {
             for my $file ($svnlook->deleted()) {
                 my $to = _post_where_to($absbase, $file, $from, $conf->{to});
-                next unless -f $to;
+                next unless defined $to && -f $to;
                 if (my $rotate = $conf->{rotate}) {
                     _rotate($to, $rotate);
                 } else {
@@ -202,41 +211,44 @@ sub _functor {
     };
 }
 
-# Return the server-side absolute path mapping for the configuration
-# file. $absbase is the absolute path to the repo's conf
-# directory. $file is the path of a file added, modified, or deleted
-# in the commit. $from and $to are the configured mapping.
+# Return the server-side absolute path mapping for the configuration file, or
+# undef if $file doesn't match $from. $absbase is the absolute path to the
+# repo's conf directory. $file is the path of a file added, modified, or
+# deleted in the commit. $from and $to are the configured mapping.
 
 sub _post_where_to {
     my ($absbase, $file, $from, $to) = @_;
 
     if (is_string($from)) {
-        next if $file ne $from;
+        return if $file ne $from;
     } else {
-        next if $file !~ $from;
+        return if $file !~ $from;
         # interpolate backreferences
-        $to = eval qq{"$to"};   ## no critic
+        $to = eval qq{"$to"};   ## no critic (BuiltinFunctions::ProhibitStringyEval)
     }
 
-    $to = abs_path(catfile($SVN::Hooks::Repo, 'conf', $to));
-    if (-d $to) {
-        $to = catfile($to, (File::Spec->splitpath($file))[2]);
-    }
-
-    $absbase eq substr($to, 0, length($absbase))
+    $to !~ m@(?:^|/)\.\.(?:/|$)@
         or croak <<"EOS";
 $HOOK: post-commit aborted for: $file
 
 This means that $file was committed but the associated
 configuration file wasn't generated because its specified
 location ($to)
-isn't below the repository's configuration directory
-($absbase).
+contains a '..' path component which is not accepted by this hook.
 
 Please, correct the ${HOOK}'s second argument.
 EOS
 
-    return $to;
+    my $is_directory = ($to =~ s:/$::);
+
+    $to =~ s:^/+::;
+
+    my $abs_to = catfile($absbase, $to);
+    if ($is_directory || -d $abs_to) {
+        $abs_to = catfile($abs_to, (File::Spec->splitpath($file))[2]);
+    }
+
+    return $abs_to;
 }
 
 # Rotates file $to $rotate times.
@@ -265,7 +277,7 @@ SVN::Hooks::UpdateConfFile - Maintain the repository configuration versioned.
 
 =head1 VERSION
 
-version 1.23
+version 1.27
 
 =head1 SYNOPSIS
 
@@ -294,9 +306,15 @@ FROM can be a string or a qr/Regexp/ specifying the file path relative
 to the repository's root (e.g. "trunk/src/version.c" or
 "qr:^conf/(\w+).conf$:").
 
-TO is a path relative to the C</repo/conf> directory in the server. It
-can be an explicit file name or a directory, in which case the
-basename of FROM is used as the name of the destination file.
+TO must be a relative path indicating where the original file must be copied
+to below the C</repo/conf> directory in the server. It can be an explicit
+file name or a directory, in which case the basename of FROM is used as the
+name of the destination file. Non-existing directory components of TO are
+automatically created.
+
+Note that if the path doesn't exist the hook assumes that it should be a
+file. To make sure it's understood as a directory you may end it with a
+forward slash (/).
 
 If FROM is a qr/Regexp/, TO is evaluated as a string in order to allow
 for the interpolation of capture buffers from the regular
@@ -413,7 +431,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by CPqD.
+This software is copyright (c) 2014 by CPqD.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
